import type { CreateDonor } from '../models/CreateDonor';
import type { ResponseDonor } from '../models/ResponseDonor';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { UpdateDonor } from '../models/UpdateDonor';
export declare class DonorService {
    /**
     * Get all
     * Lists all runners from all teams/orgs. <br> This includes the runner's group and distance ran.
     * @returns ResponseDonor
     * @throws ApiError
     */
    static donorControllerGetAll(): Promise<Array<ResponseDonor>>;
    /**
     * Post
     * Create a new runner. <br> Please remeber to provide the runner's group's id.
     * @param requestBody CreateDonor
     * @returns ResponseDonor
     * @throws ApiError
     */
    static donorControllerPost(requestBody?: CreateDonor): Promise<ResponseDonor>;
    /**
     * Get one
     * Lists all information about the runner whose id got provided.
     * @param id
     * @returns ResponseDonor
     * @throws ApiError
     */
    static donorControllerGetOne(id: number): Promise<ResponseDonor>;
    /**
     * Put
     * Update the runner whose id you provided. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdateDonor
     * @returns ResponseDonor
     * @throws ApiError
     */
    static donorControllerPut(id: number, requestBody?: UpdateDonor): Promise<ResponseDonor>;
    /**
     * Remove
     * Delete the runner whose id you provided. <br> If no runner with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @returns ResponseDonor
     * @returns ResponseEmpty
     * @throws ApiError
     */
    static donorControllerRemove(id: number, force?: boolean): Promise<ResponseDonor | ResponseEmpty>;
}
