import type { CreateScan } from '../models/CreateScan';
import type { CreateTrackScan } from '../models/CreateTrackScan';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponseScan } from '../models/ResponseScan';
import type { ResponseTrackScan } from '../models/ResponseTrackScan';
import type { UpdateScan } from '../models/UpdateScan';
export declare class ScanService {
    /**
     * Get all
     * Lists all scans (normal or track) from all runners. <br> This includes the scan's runner's distance ran.
     * @returns any
     * @throws ApiError
     */
    static scanControllerGetAll(): Promise<(Array<ResponseScan> | Array<ResponseTrackScan>)>;
    /**
     * Post
     * Create a new scan. <br> Please remeber to provide the scan's runner's id and distance for normal scans.
     * @param requestBody CreateScan
     * @returns ResponseScan
     * @throws ApiError
     */
    static scanControllerPost(requestBody?: CreateScan): Promise<ResponseScan>;
    /**
     * Get one
     * Lists all information about the scan whose id got provided. This includes the scan's runner's distance ran.
     * @param id
     * @returns any
     * @throws ApiError
     */
    static scanControllerGetOne(id: number): Promise<(ResponseScan | ResponseTrackScan)>;
    /**
     * Put
     * Update the scan whose id you provided. <br> Please remember that ids can't be changed and distances must be positive.
     * @param id
     * @param requestBody UpdateScan
     * @returns ResponseScan
     * @throws ApiError
     */
    static scanControllerPut(id: number, requestBody?: UpdateScan): Promise<ResponseScan>;
    /**
     * Remove
     * Delete the scan whose id you provided. <br> If no scan with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @returns ResponseScan
     * @returns ResponseEmpty
     * @throws ApiError
     */
    static scanControllerRemove(id: number, force?: boolean): Promise<ResponseScan | ResponseEmpty>;
    /**
     * Post track scans
     * Create a new track scan. <br> This is just a alias for posting /scans
     * @param requestBody CreateTrackScan
     * @returns ResponseScan
     * @throws ApiError
     */
    static scanControllerPostTrackScans(requestBody?: CreateTrackScan): Promise<ResponseScan>;
}
