import type { CreateUser } from '../models/CreateUser';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { UpdateUser } from '../models/UpdateUser';
import type { User } from '../models/User';
import type { UserGroupNotFoundError } from '../models/UserGroupNotFoundError';
export declare class UserService {
    /**
     * Get all
     * Lists all users. <br> This includes their groups and permissions directly granted to them (if existing/associated).
     * @returns User
     * @throws ApiError
     */
    static userControllerGetAll(): Promise<Array<User>>;
    /**
     * Post
     * Create a new user. <br> If you want to grant permissions to the user you have to create them seperately by posting to /api/permissions after creating the user.
     * @param requestBody CreateUser
     * @returns any
     * @throws ApiError
     */
    static userControllerPost(requestBody?: CreateUser): Promise<(User | UserGroupNotFoundError)>;
    /**
     * Get one
     * Lists all information about the user whose id got provided. <br> Please remember that only permissions granted directly to the user will show up here, not permissions inherited from groups.
     * @param id
     * @returns User
     * @throws ApiError
     */
    static userControllerGetOne(id: number): Promise<User>;
    /**
     * Put
     * Update the user whose id you provided. <br> To change the permissions directly granted to the user please use /api/permissions instead. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdateUser
     * @returns User
     * @throws ApiError
     */
    static userControllerPut(id: number, requestBody?: UpdateUser): Promise<User>;
    /**
     * Remove
     * Delete the user whose id you provided. <br> If there are any permissions directly granted to the user they will get deleted as well. <br> If no user with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @returns User
     * @returns ResponseEmpty
     * @throws ApiError
     */
    static userControllerRemove(id: number, force?: boolean): Promise<User | ResponseEmpty>;
}
